@@ -2393,6 +2393,15 @@ class USBContext:
 
     # TODO: handleEventsTimeoutCompleted
 
+    @_validContext
+    def interruptEventHandler(self):
+        """
+        Interrupt any active thread that is handling events.
+        This is mainly useful for interrupting a dedicated event handling thread
+        when the application wishes to exit.
+        """
+        libusb1.libusb_interrupt_event_handler(self.__context_p)
+
     @_validContext
     def setPollFDNotifiers(
             self, added_cb=None, removed_cb=None, user_data=None):
@@ -2424,21 +2433,26 @@ class USBContext:
         if not self.__has_pollfd_finalizer:
             self.__has_pollfd_finalizer = True
             try:
-                self.__registerFinalizer(
-                    handle=id(self),
-                    finalizer=weakref.finalize(
-                        self,
-                        self.__finalizePollFDNotifiers, # Note: staticmethod
-                        context_p=self.__context_p,
-                        libusb_set_pollfd_notifiers=libusb1.libusb_set_pollfd_notifiers,
+                finalizer_handle = id(self)
+                finalizer_dict = self.__finalizer_dict
+                finalizer = weakref.finalize(
+                    self,
+                    self.__finalizePollFDNotifiers, # Note: staticmethod
+                    context_p=self.__context_p,
+                    unregisterFinalizer=functools.partial(
+                        finalizer_dict.pop,
+                        finalizer_handle,
                     ),
+                    libusb_set_pollfd_notifiers=libusb1.libusb_set_pollfd_notifiers,
                 )
+                self.__registerFinalizer(finalizer_handle, finalizer)
             except ValueError: # Already registered
                 pass
 
     @staticmethod
     def __finalizePollFDNotifiers(
         context_p,
+        unregisterFinalizer,
         libusb_set_pollfd_notifiers,
 
         null_pointer=_null_pointer,
@@ -2451,6 +2465,7 @@ class USBContext:
             removed_cb_p,
             null_pointer,
         )
+        unregisterFinalizer()
 
     @_validContext
     def getNextTimeout(self):
